==> liblaf_lime-0.1.1.tar.gz: liblaf_lime-0.1.1/CHANGELOG.md <==
# Changelog

## [0.1.1](https://github.com/liblaf/lime/compare/v0.1.0..v0.1.1) - 20250126

### 📝 Documentation

- update README and project metadata for clarity and accuracy - ([e3a8387](https://github.com/liblaf/lime/commit/e3a838756263a72eeb1273402fde6d1bafaaf757))
- add CLI help documentation generation - ([d7796e1](https://github.com/liblaf/lime/commit/d7796e11a36cd499871447a15233c40d98dfebd8))
- update README and feature descriptions for clarity and consistency - ([badd1c1](https://github.com/liblaf/lime/commit/badd1c10c6c581a1fd3c95b4d9bad308ee7ded7d))

### ♻ Code Refactoring

- reduce maximum suggested topics from 20 to 10 - ([8ccf5be](https://github.com/liblaf/lime/commit/8ccf5be073607f971a957f2d719a5733129ea858))

### ❤️ New Contributors

- @liblaf made their first contribution

## [0.1.0](https://github.com/liblaf/lime/compare/v0.0.2..v0.1.0) - 20250125

### 💥 BREAKING CHANGES

- next (#15) - ([99e128e](https://github.com/liblaf/lime/commit/99e128eefa52fa4b07ad9a404a892eca728b48a0))

### ✨ Features

- **live:** add transient option to live action - ([dfd597a](https://github.com/liblaf/lime/commit/dfd597ad4e7996b6060d37b92a19df5e54014df8))
- **repo:** add GitHub repository description generation and update functionality - ([28acafc](https://github.com/liblaf/lime/commit/28acafcdd5dcd2a814b34bfb3978ae390e00b8f7))
- enhance README generation with AI-powered features and descriptions - ([d9fe575](https://github.com/liblaf/lime/commit/d9fe575120335e3d020d539d8427173be328f55d))

### ⬆️ Dependencies

- **deps:** update dependency httpx to >=0.28.1,<0.29 (#16) - ([922266a](https://github.com/liblaf/lime/commit/922266ab523672eabfc2d5a963fb36b5912cb7a9))

### 📝 Documentation

- update README badge links and formatting - ([fb02378](https://github.com/liblaf/lime/commit/fb0237827bf5243369fb99dbfdba96c559179a29))

## [0.0.2](https://github.com/liblaf/lime/compare/v0.0.1..v0.0.2) - 20241130

### 📝 Documentation

- update CLI command references to use 'ai' instead of 'ai-cli' - ([06bc78a](https://github.com/liblaf/lime/commit/06bc78a861c91bd06c5050e146075684b80d186c))
- update README and utility function for consistency - ([59e20ee](https://github.com/liblaf/lime/commit/59e20ee575057d7b5f75c84bb3810e4b93066d21))

### ♻ Code Refactoring

- rename LLM CLI to AI CLI for broader applicability - ([53b7d9d](https://github.com/liblaf/lime/commit/53b7d9d9ad2e4e25703df9e0e0cce5f3ffbed7c0))

## [0.0.1](https://github.com/liblaf/lime/compare/v0.0.0..v0.0.1) - 20241130

### 🐛 Bug Fixes

- clear logging handlers for LiteLLM to prevent duplicate logs - ([418effd](https://github.com/liblaf/lime/commit/418effd5caa375abc7f4dff2883be84c2e1e9b82))

### 📝 Documentation

- update GitHub links in README - ([b704a54](https://github.com/liblaf/lime/commit/b704a54f11dd769af19a95a07b744ea5e26cf524))
- update README badges to use PyPI release info - ([fc05511](https://github.com/liblaf/lime/commit/fc0551153817065c7e35c9c9759005b4f0a3ff96))
- update README and pyproject.toml with improved URLs and badges - ([954ad5f](https://github.com/liblaf/lime/commit/954ad5f6b0d321e49689f530e36ce0fdb5ab92e1))

### ♻ Code Refactoring

- rename project and related references to 'ai-cli' - ([ea2baaf](https://github.com/liblaf/lime/commit/ea2baaf45ac5bac8e3c1cd20afe24cca42ffe573))
- streamline CLI and logging initialization - ([9e04a97](https://github.com/liblaf/lime/commit/9e04a97e14bacda010ea0cda02d0684938637902))

## [0.0.0] - 20241129

### ✨ Features

- add logging and model option to CLI - ([411658e](https://github.com/liblaf/lime/commit/411658e59ecc7da9e3eebb57360a2795100f8022))
- add commit command to generate commit messages using LLM - ([813593c](https://github.com/liblaf/lime/commit/813593ce3009390eaf9b92e6c256c031cb35133e))

### 📝 Documentation

- enhances README with detailed project information - ([6bc3631](https://github.com/liblaf/lime/commit/6bc363106b0acd8f2e83a43094fc80ba3f216c45))
- update help documentation formatting - ([5c28cfe](https://github.com/liblaf/lime/commit/5c28cfe8521110e25c351d0970cf2bed17215ea4))
- update commit message guidelines - ([de62d93](https://github.com/liblaf/lime/commit/de62d93c4bfcc61d54f8c38478f5214cdee66342))
- standardize commit message type descriptions - ([a2abf54](https://github.com/liblaf/lime/commit/a2abf549ae7e90002867446963f4a8ff5eac912e))
- add CLI usage documentation - ([6ad48bd](https://github.com/liblaf/lime/commit/6ad48bd1073e97f790450e0c4ad42c114315f0e6))
- update repository description and topic instructions - ([e242291](https://github.com/liblaf/lime/commit/e242291a557a6dcb480fe685bdf16666d75c1818))
- add project title to README - ([c33e7e4](https://github.com/liblaf/lime/commit/c33e7e4a67271a6cd7dcb814e94bcc7a63909d77))

### ♻ Code Refactoring

- improve interactive CLI output and usage display - ([852f390](https://github.com/liblaf/lime/commit/852f39090c318695690b01703537dcd13ca8383e))
- reorganize and optimize configuration and command handling - ([d62896e](https://github.com/liblaf/lime/commit/d62896e4650eb8eb971d58f4eaab6dc5dc780e03))
- enhance commit command with path filtering and prefix handling - ([301512f](https://github.com/liblaf/lime/commit/301512f191a415dabcaa2bc1a05d71ab17b95964))
- improve tag extraction and type annotations - ([f1fbca3](https://github.com/liblaf/lime/commit/f1fbca3a80a35c3993071c387246681e013a3930))
- reorganize module structure for clarity - ([239e765](https://github.com/liblaf/lime/commit/239e765236374126eb2ee696f68851cc70209fb2))
- reorganize repository structure and improve command handling - ([e39e58e](https://github.com/liblaf/lime/commit/e39e58e07e10f98cbb30d36cdf38bce4923ca753))
- streamline configuration and improve integration with external libraries - ([142fab2](https://github.com/liblaf/lime/commit/142fab2a8c42b4df2792188d1f08054069f9c0b6))

### 🔧 Continuous Integration

- add GitHub Actions workflow for CI and release automation - ([f20c617](https://github.com/liblaf/lime/commit/f20c617038972d5ecbc395323d6face1785b2918))

### ❤️ New Contributors

- @release-please[bot] made their first contribution in [#10](https://github.com/liblaf/lime/pull/10)
- @liblaf made their first contribution
- @renovate[bot] made their first contribution in [#8](https://github.com/liblaf/lime/pull/8)
- @liblaf-bot[bot] made their first contribution

==> liblaf_lime-0.1.4.tar.gz: liblaf_lime-0.1.4/CHANGELOG.md <==
# Changelog

## [0.1.4](https://github.com/liblaf/lime/compare/v0.1.3..v0.1.4) - 2025-02-16

### ⬆️ Dependencies

- **deps:** update dependency liblaf-grapes to >=0.0.5,<0.0.6 (#27) - ([39e41f9](https://github.com/liblaf/lime/commit/39e41f96013647c2d3f2975e56c28befa3e5e0dd))
- **deps:** update dependency liblaf-grapes to >=0.0.4,<0.0.5 (#25) - ([49f1a5e](https://github.com/liblaf/lime/commit/49f1a5eda51fa4c75391394d149676594ca5d7f9))

### ❤️ New Contributors

- @liblaf made their first contribution
- @renovate[bot] made their first contribution in [#27](https://github.com/liblaf/lime/pull/27)

## [0.1.3](https://github.com/liblaf/lime/compare/v0.1.2..v0.1.3) - 2025-02-03

### ⬆️ Dependencies

- **deps:** update dependency liblaf-grapes to >=0.0.3,<0.0.4 (#23) - ([c9ec6ae](https://github.com/liblaf/lime/commit/c9ec6ae8c23ef22ecbec4553a1242fe15f1d7143))

## [0.1.2](https://github.com/liblaf/lime/compare/v0.1.1..v0.1.2) - 2025-01-27

### ✨ Features

- **cli:** add `--model` and `--add` options to repo commands - ([842f5d1](https://github.com/liblaf/lime/commit/842f5d11ae4adc77b0cb0f8bb0e21217ad2a6c51))
- **git:** add `ls_files` utility and update ignore patterns - ([6a7f970](https://github.com/liblaf/lime/commit/6a7f97040eb4dfb4b7c235ef22a2d718fbbc0849))
- add commit message sanitizer - ([b8cf795](https://github.com/liblaf/lime/commit/b8cf795c3eae7655ba2debbabd7c369ae9a3e572))
- add max-len and n-topics options for repo commands - ([7953524](https://github.com/liblaf/lime/commit/79535242376f9175935d6f12472fe63862c64f7f))

### 🐛 Bug Fixes

- trigger release - ([cef7aaa](https://github.com/liblaf/lime/commit/cef7aaa23ed34c772401df5589f4088304961b43))
- adjust topic count calculation in CLI - ([2b9e3c4](https://github.com/liblaf/lime/commit/2b9e3c4d60d38633d8f1d4bd199394a37892e7c1))

### 📝 Documentation

- update description length guideline in prompts - ([632a6f8](https://github.com/liblaf/lime/commit/632a6f8359c4c9bc8eeb13cec3cfafab935a3b7c))
- simplify README.md by removing redundant badge definitions - ([80f794d](https://github.com/liblaf/lime/commit/80f794d29f6d5c16151196b2d87812a51afbc434))

## [0.1.1](https://github.com/liblaf/lime/compare/v0.1.0..v0.1.1) - 2025-01-26

### 📝 Documentation

- update README and project metadata for clarity and accuracy - ([e3a8387](https://github.com/liblaf/lime/commit/e3a838756263a72eeb1273402fde6d1bafaaf757))
- add CLI help documentation generation - ([d7796e1](https://github.com/liblaf/lime/commit/d7796e11a36cd499871447a15233c40d98dfebd8))
- update README and feature descriptions for clarity and consistency - ([badd1c1](https://github.com/liblaf/lime/commit/badd1c10c6c581a1fd3c95b4d9bad308ee7ded7d))

### ♻ Code Refactoring

- reduce maximum suggested topics from 20 to 10 - ([8ccf5be](https://github.com/liblaf/lime/commit/8ccf5be073607f971a957f2d719a5733129ea858))

### ❤️ New Contributors

- @github-actions[bot] made their first contribution in [#20](https://github.com/liblaf/lime/pull/20)

## [0.1.0](https://github.com/liblaf/lime/compare/v0.0.2..v0.1.0) - 2025-01-25

### 💥 BREAKING CHANGES

- next (#15) - ([99e128e](https://github.com/liblaf/lime/commit/99e128eefa52fa4b07ad9a404a892eca728b48a0))

### ✨ Features

- **live:** add transient option to live action - ([dfd597a](https://github.com/liblaf/lime/commit/dfd597ad4e7996b6060d37b92a19df5e54014df8))
- **repo:** add GitHub repository description generation and update functionality - ([28acafc](https://github.com/liblaf/lime/commit/28acafcdd5dcd2a814b34bfb3978ae390e00b8f7))
- enhance README generation with AI-powered features and descriptions - ([d9fe575](https://github.com/liblaf/lime/commit/d9fe575120335e3d020d539d8427173be328f55d))

### ⬆️ Dependencies

- **deps:** update dependency httpx to >=0.28.1,<0.29 (#16) - ([922266a](https://github.com/liblaf/lime/commit/922266ab523672eabfc2d5a963fb36b5912cb7a9))

### 📝 Documentation

- update README badge links and formatting - ([fb02378](https://github.com/liblaf/lime/commit/fb0237827bf5243369fb99dbfdba96c559179a29))

## [0.0.2](https://github.com/liblaf/lime/compare/v0.0.1..v0.0.2) - 2024-11-30

### 📝 Documentation

- update CLI command references to use 'ai' instead of 'ai-cli' - ([06bc78a](https://github.com/liblaf/lime/commit/06bc78a861c91bd06c5050e146075684b80d186c))
- update README and utility function for consistency - ([59e20ee](https://github.com/liblaf/lime/commit/59e20ee575057d7b5f75c84bb3810e4b93066d21))

### ♻ Code Refactoring

- rename LLM CLI to AI CLI for broader applicability - ([53b7d9d](https://github.com/liblaf/lime/commit/53b7d9d9ad2e4e25703df9e0e0cce5f3ffbed7c0))

## [0.0.1](https://github.com/liblaf/lime/compare/v0.0.0..v0.0.1) - 2024-11-30

### 🐛 Bug Fixes

- clear logging handlers for LiteLLM to prevent duplicate logs - ([418effd](https://github.com/liblaf/lime/commit/418effd5caa375abc7f4dff2883be84c2e1e9b82))

### 📝 Documentation

- update GitHub links in README - ([b704a54](https://github.com/liblaf/lime/commit/b704a54f11dd769af19a95a07b744ea5e26cf524))
- update README badges to use PyPI release info - ([fc05511](https://github.com/liblaf/lime/commit/fc0551153817065c7e35c9c9759005b4f0a3ff96))
- update README and pyproject.toml with improved URLs and badges - ([954ad5f](https://github.com/liblaf/lime/commit/954ad5f6b0d321e49689f530e36ce0fdb5ab92e1))

### ♻ Code Refactoring

- rename project and related references to 'ai-cli' - ([ea2baaf](https://github.com/liblaf/lime/commit/ea2baaf45ac5bac8e3c1cd20afe24cca42ffe573))
- streamline CLI and logging initialization - ([9e04a97](https://github.com/liblaf/lime/commit/9e04a97e14bacda010ea0cda02d0684938637902))

## [0.0.0] - 2024-11-29

### ✨ Features

- add logging and model option to CLI - ([411658e](https://github.com/liblaf/lime/commit/411658e59ecc7da9e3eebb57360a2795100f8022))
- add commit command to generate commit messages using LLM - ([813593c](https://github.com/liblaf/lime/commit/813593ce3009390eaf9b92e6c256c031cb35133e))

### 📝 Documentation

- enhances README with detailed project information - ([6bc3631](https://github.com/liblaf/lime/commit/6bc363106b0acd8f2e83a43094fc80ba3f216c45))
- update help documentation formatting - ([5c28cfe](https://github.com/liblaf/lime/commit/5c28cfe8521110e25c351d0970cf2bed17215ea4))
- update commit message guidelines - ([de62d93](https://github.com/liblaf/lime/commit/de62d93c4bfcc61d54f8c38478f5214cdee66342))
- standardize commit message type descriptions - ([a2abf54](https://github.com/liblaf/lime/commit/a2abf549ae7e90002867446963f4a8ff5eac912e))
- add CLI usage documentation - ([6ad48bd](https://github.com/liblaf/lime/commit/6ad48bd1073e97f790450e0c4ad42c114315f0e6))
- update repository description and topic instructions - ([e242291](https://github.com/liblaf/lime/commit/e242291a557a6dcb480fe685bdf16666d75c1818))
- add project title to README - ([c33e7e4](https://github.com/liblaf/lime/commit/c33e7e4a67271a6cd7dcb814e94bcc7a63909d77))

### ♻ Code Refactoring

- improve interactive CLI output and usage display - ([852f390](https://github.com/liblaf/lime/commit/852f39090c318695690b01703537dcd13ca8383e))
- reorganize and optimize configuration and command handling - ([d62896e](https://github.com/liblaf/lime/commit/d62896e4650eb8eb971d58f4eaab6dc5dc780e03))
- enhance commit command with path filtering and prefix handling - ([301512f](https://github.com/liblaf/lime/commit/301512f191a415dabcaa2bc1a05d71ab17b95964))
- improve tag extraction and type annotations - ([f1fbca3](https://github.com/liblaf/lime/commit/f1fbca3a80a35c3993071c387246681e013a3930))
- reorganize module structure for clarity - ([239e765](https://github.com/liblaf/lime/commit/239e765236374126eb2ee696f68851cc70209fb2))
- reorganize repository structure and improve command handling - ([e39e58e](https://github.com/liblaf/lime/commit/e39e58e07e10f98cbb30d36cdf38bce4923ca753))
- streamline configuration and improve integration with external libraries - ([142fab2](https://github.com/liblaf/lime/commit/142fab2a8c42b4df2792188d1f08054069f9c0b6))

### 🔧 Continuous Integration

- add GitHub Actions workflow for CI and release automation - ([f20c617](https://github.com/liblaf/lime/commit/f20c617038972d5ecbc395323d6face1785b2918))

### ❤️ New Contributors

- @release-please[bot] made their first contribution in [#10](https://github.com/liblaf/lime/pull/10)
- @liblaf made their first contribution
- @renovate[bot] made their first contribution in [#8](https://github.com/liblaf/lime/pull/8)
- @liblaf-bot[bot] made their first contribution
